@@ -15,9 +15,11 @@ class HiddenProfiles(object):
 
 def post_install(context):
     """Post install script"""
-    # Do something at the end of the installation of this package.
 
 
 def uninstall(context):
     """Uninstall script"""
-    # Do something at the end of the uninstallation of this package.
+
+
+def coordinates_controlpanel_install(context):
+    """Coordinates controlpanel script"""
